# unithon - Python library to unify datasets

[![Python Version](https://img.shields.io/pypi/pyversions/unithon.svg)](https://pypi.org/project/unithon/)
[![PyPi Version](https://img.shields.io/pypi/v/unithon.svg)](https://pypi.org/project/unithon/)
[![Package Status](https://img.shields.io/pypi/status/unithon.svg)](https://pypi.org/project/unithon/)
[![Build Status](https://img.shields.io/travis/dvidgar/unithon/master.svg?label=Travis%20CI&logo=travis&logoColor=white)](https://travis-ci.org/dvidgar/unithon)
[![Documentation Status](https://readthedocs.org/projects/unithon/badge/?version=latest)](https://unithon.readthedocs.io/)
[![Downloads](https://img.shields.io/pypi/dm/unithon.svg?style=flat)](https://pypistats.org/packages/unithon)

## Introduction

**unithon** is a python library for unifying heterogeneous datasets, primarily focused on IoT data processing. 
Several datasets with different structure and refresh times can easily be combined into a single well-formatted dataset.
Furthermore, it provides some commonly used functions for data processing.

## Installation

In order to get this package working you will need to install it using pip by typing on the terminal:

``$ python -m pip install unithon --upgrade``

Or just install the current release or a specific release version such as:

``$ python -m pip install unithon==0.1``

## Contribute

As this is an open source project it is open to contributions, bug reports, bug fixes, documentation improvements, 
enhancements and ideas.

Also there is an open tab of [issues](https://github.com/dvidgar/unithon/issues) where anyone can contribute opening 
new issues if needed or navigate through them in order to solve them or contribute to its solving.